@@ -1,9 +1,9 @@
 package Egg::Response::TieCookie;
 #
 # Copyright 2006 Bee Flag, Corp. All Rights Reserved.
-# Masatoshi Mizuno E<lt>mizunoE<64>bomcity.comE<gt>
+# Masatoshi Mizuno E<lt>lusheE<64>cpan.orgE<gt>
 #
-# $Id: TieCookie.pm 185 2007-02-17 07:18:18Z lushe $
+# $Id: TieCookie.pm 245 2007-02-24 18:21:27Z lushe $
 #
 use strict;
 use warnings;
@@ -103,7 +103,7 @@ L<Egg::Release>, L<Egg::Response>,
 
 =head1 AUTHOR
 
-Masatoshi Mizuno, E<lt>mizunoE<64>bomcity.comE<gt>
+Masatoshi Mizuno, E<lt>lusheE<64>cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
